==> o3-form-0.5.0.tgz: package/esm/PasswordInput.js <==
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { uidBuilder } from "@financial-times/o-utils";
import { LabeledFormField } from "./fieldComponents/FormField";
import { CheckBoxItem } from "./CheckBox";
const uniqueId = uidBuilder("o3-form-password-input");
const PasswordInput = ({
  label,
  feedback,
  description,
  disabled,
  attributes,
  inputId,
  optional
}) => {
  const id = inputId || uniqueId("_");
  const showPasswordId = `${id}-showPassword`;
  const inputClasses = ["o3-form", "o3-form-text-input"];
  if (feedback && feedback.type === "error") {
    inputClasses.push("o3-form-text-input--error");
  }
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      LabeledFormField,
      {
        label,
        feedback,
        description,
        inputId: id,
        optional,
        children: /* @__PURE__ */ jsx(
          "input",
          {
            ...attributes,
            id,
            disabled,
            className: inputClasses.join(" "),
            required: !optional,
            "aria-required": !optional,
            type: "password"
          }
        )
      }
    ),
    /* @__PURE__ */ jsxs("div", { className: "o3-password-input__controls", children: [
      /* @__PURE__ */ jsx(
        CheckBoxItem,
        {
          attributes: { disabled },
          inputId: showPasswordId,
          checkboxLabel: "Show Password"
        }
      ),
      !disabled && /* @__PURE__ */ jsx("a", { className: "o3-typography-link", href: "", children: "Forgot password?" })
    ] })
  ] });
};
export {
  PasswordInput
};

==> o3-form-0.5.2.tgz: package/esm/PasswordInput.js <==
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { uidBuilder } from "@financial-times/o-utils";
import { LabeledFormField } from "./fieldComponents/FormField";
import { CheckBoxItem } from "./CheckBox";
const uniqueId = uidBuilder("o3-form-password-input");
const PasswordInput = ({
  label,
  feedback,
  description,
  disabled,
  attributes,
  inputId,
  optional
}) => {
  const id = inputId || uniqueId("_");
  const showPasswordId = `${id}-showPassword`;
  const inputClasses = ["o3-form", "o3-form-text-input"];
  if (feedback && feedback.type === "error") {
    inputClasses.push("o3-form-text-input--error");
  }
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      LabeledFormField,
      {
        label,
        feedback,
        description,
        inputId: id,
        optional,
        children: /* @__PURE__ */ jsx(
          "input",
          {
            ...attributes,
            id,
            disabled,
            className: inputClasses.join(" "),
            required: !optional,
            "aria-required": !optional,
            type: "password"
          }
        )
      }
    ),
    /* @__PURE__ */ jsxs("div", { className: "o3-password-input__controls", children: [
      /* @__PURE__ */ jsx(
        CheckBoxItem,
        {
          attributes: { disabled },
          inputId: showPasswordId,
          checkboxLabel: "Show password"
        }
      ),
      !disabled && /* @__PURE__ */ jsx("a", { className: "o3-typography-link", href: "", children: "Forgot password?" })
    ] })
  ] });
};
export {
  PasswordInput
};
